<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Cliente;
use App\Models\User;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Hash;
use App\Mail\WelcomeClientMail;

class ClientController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
        $clients = Cliente::all();
        return view('admin.clients.index', compact('clients'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //

        $client_email           = Cliente::where('email', $request->input('email'));
        $client_indentification = Cliente::where([
            'identificacion_tipo' => $request->input('identificacion_tipo'),
            'identificacion_codigo' => $request->input('identificacion_codigo')
        ]);
        $client_phone           = Cliente::where('telefono', $request->input('telefono'));

        if($client_indentification->count() > 0){
            return response("Ya existe un cliente con esta identificación (Cédula o RIF)", 403)->header('Content-Type', 'application/json');
        }

        if($client_email->count() > 0){
            return response("Correo Electrónico ya existe", 403)->header('Content-Type', 'application/json');
        }
        
        if($client_phone->count() > 0){
            return response("Telefono ya existente", 403)->header('Content-Type', 'application/json');
        }

        if(Cliente::create($request->all())){

            $hash_verificacion = str_replace("/", "a", Hash::make($request->input('email')));

            $user           = new User;
            $user->role_id  = 3;
            $user->username = $request->input('identificacion_codigo');
            $user->email    = $request->input('email');
            $user->password = Hash::make($request->input('password'));
            
            if($user->save()){    
                $mail_confirmation = new WelcomeClientMail('no-reply@oasisinversiones.com', 'Oasis Inversiones', 
                        'Confirmación de Registro', 'soporte@oasisinversiones.com', array(
                        'client'             => "{$request->input('nombres')} {$request->input('apellidos')}",
                        'user'               => "{$request->input('identificacion_codigo')}",
                        'email'              => "{$request->input('email')}",
                        'token_verificacion' => "{$hash_verificacion}"
                ));
                Mail::to($request->input('email'))->send($mail_confirmation);
            }

            
            return response(200)->header('Content-Type', 'application/json');
        }

        return response(403)->header('Content-Type', 'application/json');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
}
