import "./components/menu";
import "./components/forms";
import createOrder from "./api/orders/createOrder";
import createOrderDetail from "./api/orders/createOrderDetail";
import incrementInput from "./utils/incrementInput";
import decrementInput from "./utils/decrementInput";
import createCategory from "./api/categories/createCategory";
import deleteResource from "./api/deleteResource";
import getProducts from "./api/products/getProducts";
import getPaymentsMethod from "./api/payments/getPaymentsMethod";
import deleteOrderDetail from "./api/orders/deleteOrderDetail";

const closeIcons = document.querySelectorAll(".close-icon");
const addOrderBtn = document.querySelector("#addOrderBtn");
const listOptionsTriggers = document.querySelectorAll("[data-options-trigger]");
const incrementBtn = document.querySelector("#incrementBtn");
const decrementBtn = document.querySelector("#decrementBtn");
const addProductToOrder = document.querySelector("#addProductToOrder");
const openDetailsTrigger = document.querySelectorAll("[data-open]");
const backdrop = document.querySelector(".backdrop");
const addCategoryBtns = document.querySelectorAll(".add-category-btn");
const token = document.querySelector('[name="csrf-token"]').content;
const customSearch = document.querySelectorAll(".custom-search");
const proceedToCheckoutBtn = document.querySelector("#proceed-to-checkout");

if (addCategoryBtns != undefined) {
    addCategoryBtns.forEach((btn) => {
        btn.addEventListener("click", (e) => {
            e.preventDefault();
            let categoryContainers = document.querySelectorAll(
                ".categories-list .content"
            );
            createCategory(
                token,
                btn.previousElementSibling.value,
                categoryContainers,
                function () {
                    btn.previousElementSibling.value = "";
                }
            );
        });
    });
}

if (listOptionsTriggers.length > 0) {
    listOptionsTriggers.forEach((btn) => {
        btn.addEventListener("click", function (e) {
            let list = document.querySelector(
                `[data-option="${btn.dataset.optionsTrigger}"]`
            );

            if (e.target.dataset.id) {
                alert(e.target.dataset.id);
            }

            list.classList.toggle("is-show");
        });
    });
}

if (addOrderBtn != null) {
    const addOrderContainer = document.querySelector("#addOrderContainer");

    addOrderBtn.addEventListener("click", function () {
        document.body.classList.add("overflow-hidden");
        addOrderContainer.classList.add("is-show");
    });
}

if (openDetailsTrigger.length > 0) {
    openDetailsTrigger.forEach((btn) => {
        btn.addEventListener("click", function () {
            const openElement = document.querySelector(
                `[data-content='${btn.dataset.open}']`
            );

            const openElements = document.querySelectorAll("[data-content]");

            if (openElement.classList.contains("app-popup")) {
                backdrop.classList.add("is-show");
            }

            document.body.classList.add("overflow-hidden");
            openElement.classList.toggle("is-show");

            openElements.forEach((el) => {
                if (el != openElement) {
                    el.classList.remove("is-show");
                }
            });
        });
    });
}

if (backdrop != undefined) {
    backdrop.addEventListener("click", function () {
        const appPopUps = document.querySelectorAll(".app-popup");

        backdrop.classList.remove("is-show");
        document.body.classList.remove("overflow-hidden");

        appPopUps.forEach((popUp) => {
            popUp.classList.remove("is-show");
        });
    });
}

closeIcons.forEach((icon) => {
    icon.addEventListener("click", function () {
        icon.parentElement.classList.remove("is-show");
        document.body.classList.remove("overflow-hidden");
    });
});

if (incrementBtn != null) {
    incrementBtn.addEventListener("click", function () {
        let input = document.querySelector("#productAmount");
        incrementInput(input.value, input);
    });
}

if (decrementBtn != null) {
    decrementBtn.addEventListener("click", function () {
        let input = document.querySelector("#productAmount");
        decrementInput(input.value, input);
    });
}

if (addProductToOrder != null) {
    addProductToOrder.addEventListener("click", function (e) {
        const productSelected = document.querySelectorAll("[data-product]");
        const orderDetails = document.querySelector(".order-details");
        let product = {};

        productSelected.forEach((data) => {
            if (data.dataset.product == "id") {
                return (product.producto_id = data.dataset.value);
            }

            if (data.dataset.product == "qty") {
                return (product.cantidad = data.dataset.value);
            }

            if (data.dataset.product == "price") {
                return (product.precio_unitario = data.dataset.value);
            }
        });

        if (localStorage.getItem("order_id")) {
            return createOrderDetail(
                localStorage.getItem("order_id"),
                product,
                orderDetails,
                token
            );
        }
        return createOrder(product, orderDetails, token, function (id) {
            localStorage.setItem("order_id", id);
            proceedToCheckoutBtn.classList.remove("btn-blocked");
        });
    });
}

document.body.addEventListener("click", function (e) {
    const deleteDetails = document.querySelectorAll(".delete-detail");

    deleteDetails.forEach((btn) => {
        if (e.target == btn) {
            deleteOrderDetail(
                btn.dataset.id,
                btn.parentElement.dataset.id,
                btn.parentElement,
                token
            );
        }
    });

    if (e.target.classList.contains("delete-resource")) {
        let text =
            "Estas seguro de eliminar este registro" ?? e.target.dataset.text;
        if (e.target.dataset.confirm == "delete" && confirm(text)) {
            deleteResource(
                e.target.dataset.url,
                token,
                e.target.dataset.id,
                e.target.parentElement
            );
        }
    }
});

customSearch.forEach((search) => {
    let customList = "";
    if (
        search.nextElementSibling != undefined &&
        search.nextElementSibling.classList.contains("custom-list")
    ) {
        customList = search.nextElementSibling;
    } else {
        customList = search.parentElement.nextElementSibling;
    }

    search.addEventListener("input", (e) => {
        customList.classList.add("is-show");
        let searchValue = e.target.value;
        let items = customList.querySelectorAll(
            ".custom-list-item, .content-item"
        );

        items.forEach((item) => {
            let itemText = item.textContent.toLocaleLowerCase();
            if (
                itemText.indexOf(searchValue.toLocaleLowerCase()) < 0 ||
                item.dataset.key
                    .toLocaleLowerCase()
                    .indexOf(searchValue.toLocaleLowerCase()) < 0
            ) {
                return item.classList.add("hide");
            } else {
                return item.classList.remove("hide");
            }
        });
    });

    search.addEventListener("click", (e) => {
        customList.classList.toggle("is-show");

        if (customList.dataset.source == "productos") {
            getProducts(customList);
        }

        if (customList.dataset.source == "metodos_pagos") {
            getPaymentsMethod(customList);
        }
    });
});

proceedToCheckoutBtn.addEventListener("click", function () {
    alert("checkout");
});
