import { notifications } from "./components/notifications";
import signUp from "./auth/signUp";
import sendRecoverPasswordLink from "./auth/sendRecoverPasswordLink";
import checkFormIsValid from "./utils/checkFormIsValid";
import getLocation from "./utils/getLocations";

const signUpLink = document.querySelector(".sign-up-link");
const passwordResetLink = document.querySelector(".password-reset-link");
const signUpContainer = document.querySelector(".sign-up-container");
const signUpForm = signUpContainer.querySelector("form");
const passwordResetContainer = document.querySelector(
    ".reset-password-container"
);
const passwordResetForm = document.querySelector(".password-reset-form");
const formLogin = document.querySelector("#formLogin");
const token = document.querySelector('[name="csrf-token"]').content;
const closeIcons = document.querySelectorAll(".close-icon");
const locationIcon = document.querySelector(".geolocation");
const indentificacionTipo = document.querySelector("#indetificactionTipo");
const clientType = document.querySelector("[data-client-type]");

indentificacionTipo.addEventListener("change", function () {
    if (indentificacionTipo.value != "V") {
        return (clientType.value = "J");
    }
    return (clientType.value = "N");
});

if (signUpLink != null) {
    signUpLink.addEventListener("click", function (e) {
        e.preventDefault();
        signUpContainer.classList.add("is-show");
        document.body.classList.add("overflow-hidden");
    });
}

if (passwordResetLink != null) {
    passwordResetLink.addEventListener("click", function (e) {
        e.preventDefault();
        passwordResetContainer.classList.add("is-show");
        document.body.classList.add("overflow-hidden");
    });
}

closeIcons.forEach((icon) => {
    icon.addEventListener("click", function () {
        icon.parentElement.classList.remove("is-show");
        document.body.classList.remove("overflow-hidden");
    });
});

formLogin.addEventListener("submit", function (e) {
    e.preventDefault();

    if (!checkFormIsValid(formLogin)) {
        return false;
    }

    const formData = new FormData(formLogin);
    formData.append("_method", "POST");
    formData.append("_token", token);

    fetch(formLogin.action, {
        method: "POST",
        body: formData,
    })
        .then((res) => {
            if (res.status == 200) {
                let url = null;
                notifications.init("Redirigiendo...").success();
                res.json().then((data) => {
                    for (let index in data) {
                        if (index == "url") {
                            url = data[index];
                            return (document.location.href = url);
                        }
                        localStorage.setItem(index, data[index]);
                    }
                });
            }

            if (res.status == 419) {
                notifications
                    .init("Error 419: Bad Authentication, recarga la pagina")
                    .success();
                return document.location.reload();
            }

            if (res.status == 403) {
                notifications.init("Usuario o contraseña incorrecto").error();
            }
            throw new Error("Error de Autenticacion");
        })
        .catch((e) => console.log(e));
});

locationIcon.addEventListener("click", function () {
    const locationInputs = document.querySelectorAll("[data-location]");

    locationInputs.forEach((input) => {
        if (input.dataset.location == "latitude") {
            input.setAttribute("data-value", getLocation("latitude") ?? "");
            input.value = getLocation("latitude") ?? "";
        }

        if (input.dataset.location == "longitude") {
            input.setAttribute("data-value", getLocation("longitude") ?? "");
            input.value = getLocation("longitude") ?? "";
        }

        if (input.dataset.location == "address") {
            input.setAttribute("data-value", getLocation("address") ?? "");
            input.value = getLocation("address") ?? "";

            setTimeout(() => {
                input.value = localStorage.getItem("address");
            }, 500);
        }
    });
});

passwordResetForm.addEventListener("submit", function (e) {
    e.preventDefault();
    if (!checkFormIsValid(passwordResetForm)) {
        return false;
    }
    notifications.init("Enviando información...").success();
    sendRecoverPasswordLink(passwordResetForm);
});

signUpForm.addEventListener("submit", function (e) {
    e.preventDefault();
    if (!checkFormIsValid(signUpForm)) {
        notifications.init("Faltan uno o mas datos por completar").error();
        return false;
    }
    notifications.init("Enviando información...").success();
    signUp(signUpForm, function () {
        signUpContainer.classList.remove("is-show");
    });
});
