<?php

use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Auth;
use App\Http\Controllers\LoginController;
use App\Http\Controllers\ResetPasswordController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\StockController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\EmployeesController;
use App\Http\Controllers\DepartmentController;
use App\Http\Controllers\ClientController;
use App\Http\Controllers\CompanyController;
use App\Http\Controllers\RolesController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\BancosController;
use App\Http\Controllers\CuentasBancoController;
use App\Http\Controllers\MetodosPagoController;
use App\Http\Controllers\TasasCambioController;
use App\Http\Controllers\RoleOptionsController;
use App\Http\Controllers\AppSettingsController;
use App\Http\Controllers\PaymentsController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/', [LoginController::class, 'index'])->name('home');

Route::prefix('auth')->group(function () {
    Route::get('/login', [LoginController::class, 'index'])->name('login');
    Route::post('/login', [LoginController::class, 'authenticate'])->name('auth');
    Route::post('/reset-password', [ResetPasswordController::class, 'sendToken'])->name('reset-pwd');
    Route::get('/change-password/{token}/{email}', [ResetPasswordController::class, 'changePassword'])->name('change-pwd');
    Route::post('/new-password', [ResetPasswordController::class, 'newPassword'])->name('new-password');
    Route::get('/confirm-email/{token}/{email}', [UserController::class, 'confirmUserEmail'])->name('confirm-email');
});

Route::post('/create-client', [ClientController::class, 'store'])->name('create-client');

Route::group(['prefix' => 'dashboard', 'middleware' => ['auth']], function () {
    Route::get('/', [DashboardController::class, 'index'])->name('dashboard');
    Route::get('/personal', [DashboardController::class, 'editProfile'])->name('profile');
    Route::resource('inventario', StockController::class, ['names' => 'stock']);
    Route::resource('categorias', CategoryController::class, ['names' => 'categories']);
    Route::resource('productos', ProductController::class, ['names' => 'products']);
    Route::resource('empleados', EmployeesController::class, ['names' => 'employees']);
    Route::resource('clientes', ClientController::class, ['names' => 'clients']);
    Route::resource('usuarios', UserController::class, ['names' => 'users']);
    Route::resource('roles', RolesController::class, ['names' => 'roles']);
    Route::resource('roles.options', RoleOptionsController::class, ['names' => 'user-options']);
    Route::resource('opciones', RoleOptionsController::class, ['names' => 'options']);
    Route::resource('pedidos', OrderController::class, ['names' => 'client-requests']);
    Route::resource('pagos', PaymentsController::class, ['names' => 'payments']);
    Route::post('pedido/{id}/detail/create', [OrderController::class, 'createDetail']);
    Route::delete('pedido/{id}/detail/{detail_id}/destroy', [OrderController::class, 'removeOrderDetail']);

    Route::get('/logout', function(){
        Session::flush();
        Auth::logout();

        return redirect()->route('home');
    })->name('logout');

    Route::get('/session', function(){
        return Session::all();
    });
    
    Route::get('/settings', [AppSettingsController::class, 'edit']);
    Route::patch('/settings/update', [AppSettingsController::class, 'update'])->name('update-settings');
    
});